==> dasu_4.11.jar: edu/northwestern/dasu/dynamic/drools/FactHttpProbeResult.java <==
package edu.northwestern.dasu.dynamic.drools;

import edu.northwestern.dasu.drools.FactProbeResult;
import edu.northwestern.dasu.measurement.types.ProbeType;
import edu.northwestern.dasu.util.Util;

public class FactHttpProbeResult extends FactProbeResult{
	
	public String url = null;
	public double downloadDuration = -1;  /*seconds*/
	public double downloadSpeed = -1; /*kpbs*/
	public int noBytes = -1;
	public int taskId = -1;
	public long time;
	public boolean error = false;

	public FactHttpProbeResult(String url) {
		super(ProbeType.HTTP);
		this.url = url;
		this.time = Util.currentGMTTime();
	}
	
	public FactHttpProbeResult(String url, double dldDuration, double dldSpeed, int noBytes, int taskId) {
		super(ProbeType.HTTP);
		this.url = url;
		this.downloadDuration = dldDuration;
		this.downloadSpeed = dldSpeed;
		this.noBytes = noBytes;
		this.taskId = taskId;
		this.time = Util.currentGMTTime();
		
	}

	public String getUrl() {
		return url;
	}

	public double getDownloadDuration() {
		return downloadDuration;
	}

	public double getDownloadSpeed() {
		return downloadSpeed;
	}

	public int getNoBytes() {
		return noBytes;
	}

	public int getTaskId() {
		return taskId;
	}

	public long getTime() {
		return time;
	}

	public boolean isError() {
		return error;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public void setDownloadDuration(double downloadDuration) {
		this.downloadDuration = downloadDuration;
	}

	public void setDownloadSpeed(double downloadSpeed) {
		this.downloadSpeed = downloadSpeed;
	}

	public void setNoBytes(int noBytes) {
		this.noBytes = noBytes;
	}

	public void setTaskId(int taskId) {
		this.taskId = taskId;
	}

	public void setTime(long time) {
		this.time = time;
	}

	public void setError(boolean error) {
		this.error = error;
	}
}

==> dasu_5.31.jar: edu/northwestern/dasu/dynamic/drools/FactHttpProbeResult.java <==
package edu.northwestern.dasu.dynamic.drools;

import edu.northwestern.cs.aqualab.cattle.jsonsimple.JSONObject;
import edu.northwestern.dasu.drools.FactProbeResult;
import edu.northwestern.dasu.measurement.types.ProbeType;
import edu.northwestern.dasu.util.Util;

public class FactHttpProbeResult extends FactProbeResult{
	
	private static final long serialVersionUID = 1L;
	public String url = null;
	public double downloadDuration = -1;  /*seconds*/
	public double downloadSpeed = -1; /*kpbs*/
	public int noBytes = -1;
	public int taskId = -1;
	public long time;
	public boolean error = false;

	public FactHttpProbeResult(String url) {
		super(ProbeType.valueOf("HTTP"));
		this.url = url;
		this.time = Util.currentGMTTime();
	}
	
	public FactHttpProbeResult(String url, double dldDuration, double dldSpeed, int noBytes, int taskId) {
		super(ProbeType.valueOf("HTTP"));
		this.url = url;
		this.downloadDuration = dldDuration;
		this.downloadSpeed = dldSpeed;
		this.noBytes = noBytes;
		this.taskId = taskId;
		this.time = Util.currentGMTTime();
		
	}

	public String getUrl() {
		return url;
	}

	public double getDownloadDuration() {
		return downloadDuration;
	}

	public double getDownloadSpeed() {
		return downloadSpeed;
	}

	public int getNoBytes() {
		return noBytes;
	}

	public int getTaskId() {
		return taskId;
	}

	public long getTime() {
		return time;
	}

	public boolean isError() {
		return error;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public void setDownloadDuration(double downloadDuration) {
		this.downloadDuration = downloadDuration;
	}

	public void setDownloadSpeed(double downloadSpeed) {
		this.downloadSpeed = downloadSpeed;
	}

	public void setNoBytes(int noBytes) {
		this.noBytes = noBytes;
	}

	public void setTaskId(int taskId) {
		this.taskId = taskId;
	}

	public void setTime(long time) {
		this.time = time;
	}

	public void setError(boolean error) {
		this.error = error;
	}
	
	public JSONObject toJSON() {

		JSONObject json = super.toJSON();
		json.remove("url");
		json.remove("taskId");
		json.remove("time");
		
		return json;
	}

}
